pub async fn benchmark_model(model: &str) -> Result<BenchmarkResult>Expand description
Benchmark a model by sending a standard prompt and measuring tokens/sec.
pub async fn benchmark_model(model: &str) -> Result<BenchmarkResult>Benchmark a model by sending a standard prompt and measuring tokens/sec.