pub async fn execute(
tool_name: &str,
args: &Value,
workspace: &str,
) -> ToolResultExpand description
Execute a tool by name with given arguments, scoped to workspace.
pub async fn execute(
tool_name: &str,
args: &Value,
workspace: &str,
) -> ToolResultExecute a tool by name with given arguments, scoped to workspace.